package chart_edb_mapping

import "time"

// ChartEdbMapping 图表指标映射表
type ChartEdbMapping struct {
	ChartEdbMappingId int       `gorm:"primaryKey;column:chart_edb_mapping_id;type:int(11);not null" json:"chartEdbMappingId"`
	ChartInfoId       int       `gorm:"uniqueIndex:idx_chart_edb;column:chart_info_id;type:int(11);default:0" json:"chartInfoId"` // 图表id
	EdbInfoId         int       `gorm:"uniqueIndex:idx_chart_edb;column:edb_info_id;type:int(11);default:0" json:"edbInfoId"`     // 指标id
	CreateTime        time.Time `gorm:"column:create_time;type:datetime" json:"createTime"`                                       // 创建时间
	ModifyTime        time.Time `gorm:"column:modify_time;type:datetime" json:"modifyTime"`                                       // 修改时间
	UniqueCode        string    `gorm:"unique;column:unique_code;type:varchar(50);default:''" json:"uniqueCode"`                  // 唯一编码
	MaxData           float64   `gorm:"column:max_data;type:double;default:0" json:"maxData"`                                     // 上限
	MinData           float64   `gorm:"column:min_data;type:double;default:0" json:"minData"`                                     // 下限
	IsOrder           int       `gorm:"column:is_order;type:tinyint(4);default:1" json:"isOrder"`                                 // 1:正序,0:逆序
	IsAxis            int       `gorm:"column:is_axis;type:tinyint(4);default:1" json:"isAxis"`                                   // 1:左轴,0:右轴
	EdbInfoType       int       `gorm:"column:edb_info_type;type:tinyint(4);default:1" json:"edbInfoType"`                        // 1:标准指标,0:领先指标
	LeadValue         int       `gorm:"column:lead_value;type:int(11);default:0" json:"leadValue"`                                // 领先值
	LeadUnit          string    `gorm:"column:lead_unit;type:varchar(10);default:''" json:"leadUnit"`                             // 领先单位
	ChartStyle        string    `gorm:"column:chart_style;type:varchar(20);default:''" json:"chartStyle"`                         // 图表类型
	ChartColor        string    `gorm:"column:chart_color;type:varchar(20);default:''" json:"chartColor"`                         // 颜色
	ChartWidth        float64   `gorm:"column:chart_width;type:double;default:0" json:"chartWidth"`                               // 线条大小
}

// TableName get sql table name.获取数据库表名
func (m *ChartEdbMapping) TableName() string {
	return "chart_edb_mapping"
}

// ChartEdbMappingColumns get sql column name.获取数据库列名
var ChartEdbMappingColumns = struct {
	ChartEdbMappingID string
	ChartInfoID       string
	EdbInfoID         string
	CreateTime        string
	ModifyTime        string
	UniqueCode        string
	MaxData           string
	MinData           string
	IsOrder           string
	IsAxis            string
	EdbInfoType       string
	LeadValue         string
	LeadUnit          string
	ChartStyle        string
	ChartColor        string
	ChartWidth        string
}{
	ChartEdbMappingID: "chart_edb_mapping_id",
	ChartInfoID:       "chart_info_id",
	EdbInfoID:         "edb_info_id",
	CreateTime:        "create_time",
	ModifyTime:        "modify_time",
	UniqueCode:        "unique_code",
	MaxData:           "max_data",
	MinData:           "min_data",
	IsOrder:           "is_order",
	IsAxis:            "is_axis",
	EdbInfoType:       "edb_info_type",
	LeadValue:         "lead_value",
	LeadUnit:          "lead_unit",
	ChartStyle:        "chart_style",
	ChartColor:        "chart_color",
	ChartWidth:        "chart_width",
}
