package chart

import (
	"encoding/json"
	"fmt"
	"hongze/hongze_yb/global"
	"hongze/hongze_yb/utils"
	"io/ioutil"
	"net/http"
	"strings"
)

type RefreshResponse struct {
	Ret         int
	Msg         string
	ErrMsg      string
	ErrCode     string
	Data        interface{}
	Success     bool `description:"true 执行成功，false 执行失败"`
	IsSendEmail bool `json:"-" description:"true 发送邮件，false 不发送邮件"`
	IsAddLog    bool `json:"-" description:"true 新增操作日志，false 不新增操作日志" `
}

// RefreshEdbData 刷新指标数据
func RefreshEdbData(edbInfoId, source int, edbCode, startDate string) (resp *RefreshResponse, err error) {
	param := make(map[string]interface{})
	param["EdbCode"] = edbCode
	param["EdbInfoId"] = edbInfoId
	param["StartDate"] = startDate
	urlStr := ``
	switch source {
	case utils.DATA_SOURCE_THS:
		urlStr = "/ths/refresh"
	case utils.DATA_SOURCE_WIND:
		urlStr = "/wind/refresh"
	case utils.DATA_SOURCE_PB:
		urlStr = "/pb/refresh"
	case utils.DATA_SOURCE_PB_FINANCE:
		urlStr = "/pb_finance/refresh"
	case utils.DATA_SOURCE_MANUAL:
		urlStr = "/manual/refresh"
	case utils.DATA_SOURCE_LZ:
		urlStr = "/lz/refresh"
	case utils.DATA_SOURCE_YS:
		urlStr = "/smm/refresh"
	case utils.DATA_SOURCE_GL:
		urlStr = "/mysteel/refresh"
	case utils.DATA_SOURCE_ZZ:
		urlStr = "/zz/refresh"
	case utils.DATA_SOURCE_DL:
		urlStr = "/dl/refresh"
	case utils.DATA_SOURCE_SH:
		urlStr = "/sh/refresh"
	case utils.DATA_SOURCE_CFFEX:
		urlStr = "/cffex/refresh"
	case utils.DATA_SOURCE_SHFE:
		urlStr = "/shfe/refresh"
	case utils.DATA_SOURCE_GIE:
		urlStr = "/gie/refresh"
	case utils.DATA_SOURCE_LT:
		urlStr = "/lt/refresh"
	case utils.DATA_SOURCE_COAL:
		urlStr = "/coal/refresh"
	}
	if urlStr == "" {
		err = fmt.Errorf(fmt.Sprint("source:", source, ";未实现该指标的刷新接口，请联系管理员"))
		return
	}
	resp, err = postRefreshEdbData(param, urlStr)
	return
}

// postRefreshEdbData 请求刷新指标数据
func postRefreshEdbData(param map[string]interface{}, urlStr string) (resp *RefreshResponse, err error) {
	edbLibUrl := ""
	if global.CONFIG.Serve.RunMode == "release" {
		edbLibUrl = "http://172.19.173.232:8300/edbapi/"
	} else {
		edbLibUrl = "http://8.136.199.33:8300/edbapi/"
	}
	postUrl := edbLibUrl + urlStr
	postData, err := json.Marshal(param)
	if err != nil {
		return
	}
	result, err := EdbLibHttpPost(postUrl, string(postData), "application/json")
	if err != nil {
		return
	}
	err = json.Unmarshal(result, &resp)
	if err != nil {
		return
	}
	return resp, nil
}

// EdbLibHttpPost post请求edb库
func EdbLibHttpPost(url, postData string, params ...string) ([]byte, error) {
	body := ioutil.NopCloser(strings.NewReader(postData))
	client := &http.Client{}
	req, err := http.NewRequest("POST", url, body)
	if err != nil {
		return nil, err
	}
	contentType := "application/x-www-form-urlencoded;charset=utf-8"
	if len(params) > 0 && params[0] != "" {
		contentType = params[0]
	}
	req.Header.Set("Content-Type", contentType)
	req.Header.Set("authorization", utils.MD5(utils.APP_EDB_LIB_NAME_EN+utils.EDB_LIB_Md5_KEY))
	resp, err := client.Do(req)
	defer resp.Body.Close()
	b, err := ioutil.ReadAll(resp.Body)
	fmt.Println("HttpPost:" + string(b))
	return b, err
}

// RefreshEdbCalculateData 刷新计算指标数据请求
func RefreshEdbCalculateData(edbInfoId int, edbCode, startDate string) (resp *RefreshResponse, err error) {
	param := make(map[string]interface{})
	param["EdbCode"] = edbCode
	param["EdbInfoId"] = edbInfoId
	param["StartDate"] = startDate
	resp, err = postRefreshEdbData(param, "/calculate/refresh")
	return
}
